#!/usr/bin/python
import sys
from datetime import datetime
import pandas as pd
import csv
import matplotlib.pyplot as plt

ROLLING_CORRELATION_WINDOW_SIZE = 12

def lastValue(x):
    try:
        reply = x[-1]
    except:
        reply = None
    return reply

def main():

    backtestFileList = ["sys1.txt", "sys2.txt", "sys3.txt", "sys4.txt"]
          
    j = 0
    
    for item in backtestFileList:
    
        print item

        tradeTimes = []
        tradeBalance = []
        
        with open(item, 'rb') as csvfile:
            reader = csv.reader(csvfile)
            i = 0
            lastBalance = 100000
            for row in reader:
                if i > 0:
                    if row[10] != "inf":
                        tradeTimes.append(datetime.strptime(row[3], '%d/%m/%Y %H:%M'))
                        tradeBalance.append(float(row[10]))
                i += 1
                
        loaded_series = pd.DataFrame(data=tradeBalance, index=tradeTimes).resample('M', how=lastValue).pct_change(fill_method='pad').fillna(0)
        
        loaded_series.columns = [item]

        if j == 0:
            allTimeSeries = loaded_series
        else:
            allTimeSeries = pd.concat([allTimeSeries, loaded_series], axis=1)
         
        j += 1
               
    allTimeSeries = allTimeSeries.fillna(0)
    correlations = allTimeSeries.corr()
    fig, ax = plt.subplots(figsize=(12,9), dpi=100)
    heatmap = ax.matshow(correlations, aspect = 'auto', origin = 'lower', cmap ="RdYlBu")
    ax.invert_yaxis()
    ax.xaxis.tick_top()

    plt.show()
    
    print allTimeSeries
    
    for index_1, system_returns_1 in enumerate(allTimeSeries.columns):
        for index_2, system_returns_2 in enumerate(allTimeSeries.columns):     
            if (index_1 > index_2) and (index_2 != index_1):
                rolling_correlation = pd.rolling_corr(allTimeSeries[system_returns_1], allTimeSeries[system_returns_2], ROLLING_CORRELATION_WINDOW_SIZE)
                fig, ax = plt.subplots(figsize=(12,9), dpi=100)
                ax.plot(rolling_correlation.index, rolling_correlation)
                ax.set_title("Rolling correlation between systems {} and {}".format(index_1+1, index_2+1))
                ax.set_xlabel('Time')
                ax.set_ylabel('Rolling Correlation')
                plt.show()
    


            
##################################
###           MAIN           ####
##################################

if __name__ == "__main__": main()
